@@ -12,7 +12,9 @@ use {
         gossip_service::discover_cluster,
         socketaddr,
     },
-    solana_ledger::{blockstore::create_new_ledger, create_new_tmp_ledger},
+    solana_ledger::{
+        blockstore::create_new_ledger, blockstore_db::ShredStorageType, create_new_tmp_ledger,
+    },
     solana_net_utils::PortRange,
     solana_rpc::{rpc::JsonRpcConfig, rpc_pubsub_service::PubSubConfig},
     solana_runtime::{
@@ -580,6 +582,7 @@ impl TestValidator {
                         .max_genesis_archive_unpacked_size
                         .unwrap_or(MAX_GENESIS_ARCHIVE_UNPACKED_SIZE),
                     solana_ledger::blockstore_db::AccessType::PrimaryOnly,
+                    ShredStorageType::default(),
                 )
                 .map_err(|err| {
                     format!(
